from setuptools import setup, find_packages

with open("README.md", "r") as f:
    long_description = f.read()

setup(
    name="oua-auth",
    version="0.3.0",
    author="Organization Unified Access",
    author_email="alexmungai964@gmail.com",
    description="A Django authentication middleware package for integrating with OUA SSO server",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://gitlab.com/lexnjugz/Organization_Unified_Access_Authentication",
    packages=find_packages(),
    include_package_data=True,
    classifiers=[
        "Development Status :: 4 - Beta",
        "Environment :: Web Environment",
        "Framework :: Django",
        "Framework :: Django :: 3.2",
        "Framework :: Django :: 4.0",
        "Framework :: Django :: 4.1",
        "Framework :: Django :: 4.2",
        "Framework :: Django :: 5.0",
        "Framework :: Django :: 5.1",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.11",
        "Programming Language :: Python :: 3.12",
        "Topic :: Internet :: WWW/HTTP",
        "Topic :: Security",
        "Topic :: Software Development :: Libraries :: Python Modules",
    ],
    python_requires=">=3.11",
    install_requires=[
        "Django>=3.2",
        "python-jose>=3.3.0",
        "bleach>=5.0.0",
        "requests>=2.25.0",
        "djangorestframework>=3.12.0",
    ],
    extras_require={
        "dev": [
            "pytest>=8.0.0",
            "pytest-django>=4.7.0",
            "pytest-cov>=4.1.0",
            "pytest-mock>=3.14.0",
            "PyJWT>=2.6.0",
            "cryptography>=41.0.0",
            "black>=24.2.0",
            "isort>=5.12.0",
            "flake8>=7.0.0",
            "build>=1.0.3",
            "twine>=5.0.0",
        ],
        "test": [
            "pytest>=8.0.0",
            "pytest-django>=4.7.0",
            "pytest-cov>=4.1.0",
            "pytest-mock>=3.14.0",
            "PyJWT>=2.6.0",
            "cryptography>=41.0.0",
        ],
    },
    zip_safe=False,
)
